@@ -11,16 +11,39 @@ from requests.cookies import cookiejar_from_dict
 
 from .constants import DEFAULT_REQUESTS_TIMEOUT
 from .facebook_scraper import FacebookScraper
-from .fb_types import Credentials, Post, RawPost
+from .fb_types import Credentials, Post, RawPost, Profile
 from .utils import html_element_to_string, parse_cookie_file
 
 
 _scraper = FacebookScraper()
 
+def set_cookies(cookies):
+    if isinstance(cookies, str):
+        cookies = parse_cookie_file(cookies)
+    elif isinstance(cookies, dict):
+        cookies = cookiejar_from_dict(cookies)
+    if cookies is not None:
+        _scraper.session.cookies = cookies
+
+def get_profile(
+    account: str,
+    **kwargs,
+ ) -> Profile:
+    """Get a Facebook user's profile information
+    Args:
+        account(str): The account of the profile.
+        cookies (Union[dict, CookieJar, str]): Cookie jar to use.
+            Can also be a filename to load the cookies from a file (Netscape format).
+    """
+    _scraper.requests_kwargs['timeout'] = kwargs.pop('timeout', DEFAULT_REQUESTS_TIMEOUT)
+    cookies = kwargs.pop('cookies', None)
+    set_cookies(cookies)
+    return _scraper.get_profile(account, **kwargs)
 
 def get_posts(
     account: Optional[str] = None,
     group: Union[str, int, None] = None,
+    post_urls: Optional[Iterator[str]] = None,
     credentials: Optional[Credentials] = None,
     **kwargs,
 ) -> Iterator[Post]:
@@ -29,6 +52,7 @@ def get_posts(
     Args:
         account (str): The account of the page.
         group (int): The group id.
+        post_urls ([str]): List of manually specified post URLs.
         credentials (Optional[Tuple[str, str]]): Tuple of email and password to login before scraping.
         timeout (int): Timeout for requests.
         page_limit (int): How many pages of posts to go through.
@@ -41,25 +65,18 @@ def get_posts(
     Yields:
         dict: The post representation in a dictionary.
     """
-    valid_args = sum(arg is not None for arg in (account, group))
+    valid_args = sum(arg is not None for arg in (account, group, post_urls))
 
     if valid_args != 1:
-        raise ValueError("You need to specify either account or group")
+        raise ValueError("You need to specify either account, group, or post_urls")
 
     _scraper.requests_kwargs['timeout'] = kwargs.pop('timeout', DEFAULT_REQUESTS_TIMEOUT)
 
     cookies = kwargs.pop('cookies', None)
 
-    if isinstance(cookies, str):
-        cookies = parse_cookie_file(cookies)
-    elif isinstance(cookies, dict):
-        cookies = cookiejar_from_dict(cookies)
-
     if cookies is not None and credentials is not None:
         raise ValueError("Can't use cookies and credentials arguments at the same time")
-
-    if cookies is not None:
-        _scraper.session.cookies = cookies
+    set_cookies(cookies)
 
     options: Union[Dict[str, Any], Set[str]] = kwargs.setdefault('options', {})
     if isinstance(options, set):
@@ -91,6 +108,9 @@ def get_posts(
     elif group is not None:
         return _scraper.get_group_posts(group, **kwargs)
 
+    elif post_urls is not None:
+        return _scraper.get_posts_by_url(post_urls, **kwargs)
+
     raise ValueError('No account nor group')
 
 
