@@ -78,6 +78,7 @@ class PostExtractor:
             'shared_text': None,
             'time': None,
             'image': None,
+            'image_lowquality': None,
             'images': None,
             'video': None,
             'video_thumbnail': None,
@@ -110,7 +111,8 @@ class PostExtractor:
             self.extract_post_id,
             self.extract_text,
             self.extract_time,
-            self.extract_image,
+            self.extract_photo_link,
+            self.extract_image_lq,
             self.extract_likes,
             self.extract_comments,
             self.extract_shares,
@@ -185,7 +187,7 @@ class PostExtractor:
         element = self.element
 
         has_more = self.more_url_regex.search(element.html)
-        if has_more:
+        if has_more and self.options.get("allow_extra_requests", True):
             match = self.post_story_regex.search(element.html)
             if match:
                 url = utils.urljoin(FB_MOBILE_BASE_URL, match.groups()[0].replace("&amp;", "&"))
@@ -263,12 +265,6 @@ class PostExtractor:
     def extract_user_id(self) -> PartialPost:
         return {'user_id': self.data_ft['content_owner_id_new']}
 
-    def extract_image(self) -> PartialPost:
-        image_link = self.extract_photo_link()
-        if image_link["image"] is not None:
-            return image_link
-        return self.extract_image_lq()
-
     def extract_image_lq(self) -> PartialPost:
         story_container = self.element.find('div.story_body_container', first=True)
         if story_container is None:
@@ -282,12 +278,12 @@ class PostExtractor:
 
             src = image_container.attrs.get('src')
             if src:
-                return {'image': src, 'images': [src]}
+                return {'image_lowquality': src}
             style = image_container.attrs.get('style', '')
             match = self.image_regex_lq.search(style)
             if match:
                 src = utils.decode_css_url(match.groups()[0])
-                return {'image': src, 'images': [src]}
+                return {'image_lowquality': src}
 
         return None
 
@@ -301,7 +297,7 @@ class PostExtractor:
 
         query_params = ('story_fbid', 'id')
         account = self.options.get('account')
-        elements = self.element.find('header a')
+        elements = self.element.find('a')
         video_post_match = None
         path = None
 
@@ -359,6 +355,8 @@ class PostExtractor:
         }
 
     def extract_photo_link(self) -> PartialPost:
+        if not self.options.get("allow_extra_requests", True):
+            return None
         images = []
         matches = list(self.photo_link.finditer(self.element.html))
         if not matches:
@@ -374,6 +372,11 @@ class PostExtractor:
                 url = match.groups()[0].replace("&amp;", "&")
                 if not url.startswith("http"):
                     url = utils.urljoin(FB_MOBILE_BASE_URL, url)
+                if url.startswith(utils.urljoin(FB_MOBILE_BASE_URL, "/photo/view_full_size/")):
+                    # Try resolve redirect
+                    response = self.request(url)
+                    if not response.url.startswith(utils.urljoin(FB_MOBILE_BASE_URL, "login.php")):
+                        url = response.html.find("a", first=True).attrs.get("href").replace("&amp;", "&")
                 images.append(url)
         image = images[0] if images else None
         return {"image": image, "images": images}
@@ -423,15 +426,19 @@ class PostExtractor:
 
         reactors = []
 
-        if self.options.get("reactors"):
+        reactors_opt = self.options.get("reactors")
+        if reactors_opt:
             """Fetch people reacting to an existing post obtained by `get_posts`.
             Note that this method may raise one more http request per post to get all reactors"""
-            logger.debug("Fetching reactors")
+            limit = 3000
+            if type(reactors_opt) in [int, float] and reactors_opt < limit:
+                limit = reactors_opt
+            logger.debug(f"Fetching {limit} reactors")
             elems = list(response.html.find("div#reaction_profile_browser>div"))
             more = response.html.find("div#reaction_profile_pager a", first=True)
-            if more:
+            if more and limit > 50:
                 url = utils.urljoin(FB_MOBILE_BASE_URL, more.attrs.get("href"))
-                url = url.replace("limit=50", f"limit={1e6}")
+                url = url.replace("limit=50", f"limit={limit - 50}")
                 logger.debug(f"Fetching {url}")
                 response = self.request(url)
                 prefix_length = len('for (;;);')
@@ -592,59 +599,73 @@ class PostExtractor:
             'available': ">This content isn't available at the moment<" not in self.element.html
         }
 
+    def parse_comment(self, comment):
+        comment_id = comment.attrs.get("id")
+        first_link = comment.find("div:not([data-sigil])>a[href]:not([data-click]):not([data-store]):not([data-sigil])", first=True)
+        comment_body_elem = comment.find('[data-sigil="comment-body"]', first=True)
+        commenter_meta = None
+        if first_link:
+            url = utils.urljoin(FB_BASE_URL, first_link.attrs.get("href"))
+            name = first_link.text
+            if "\n" in name:
+                commenter_meta, name = name.split("\n")
+        else:
+            # Adjacent div to comment body, if not logged in. No link to user page available in that case
+            url = None
+            elem = comment_body_elem.element.getprevious()
+            if elem is not None:
+                name = elem.text
+            else:
+                name = None
+
+        text = comment_body_elem.text
+        # Try to extract from the abbr element
+        date_element = comment.find('abbr', first=True)
+        if date_element:
+            date = utils.parse_datetime(date_element.text, search=False)
+        else:
+            date = None
+
+        return {
+            "comment_id": comment_id,
+            "commenter_url": url,
+            "commenter_name": name,
+            "commenter_meta": commenter_meta,
+            "comment_text": text,
+            "comment_time": date,
+        }
+
     def extract_comments_full(self):
         """Fetch comments for an existing post obtained by `get_posts`.
         Note that this method may raise multiple http requests per post to get all comments"""
         url = self.post.get('post_url').replace(FB_BASE_URL, FB_MOBILE_BASE_URL)
         logger.debug(f"Fetching {url}")
         response = self.request(url)
-        comments = list(response.html.find('div[data-sigil="comment"]'))
-        more = response.html.find("a", containing="View more comments", first=True)
+        elem = response.html.find('div[data-sigil="m-mentions-expand"]', first=True)
+        comments = list(elem.find('div[data-sigil="comment"]'))
+        more = elem.find("a", containing="View more comments", first=True)
         while more:
             url = utils.urljoin(FB_MOBILE_BASE_URL, more.attrs.get("href"))
             logger.debug(f"Fetching {url}")
             response = self.request(url)
-            more_comments = response.html.find('div[data-sigil="comment"]')
+            elem = response.html.find('div[data-sigil="m-mentions-expand"]', first=True)
+            more_comments = elem.find('div[data-sigil="comment"]')
             comments.extend(more_comments)
             more = response.html.find("a", containing="View more comments", first=True)
         logger.debug(f"Found {len(comments)} comments")
-        result = []
+        results = []
         for comment in comments:
-            comment_id = comment.attrs.get("id")
-            first_link = comment.find("div:not([data-sigil])>a[href]:not([data-click]):not([data-store]):not([data-sigil]):not([class])", first=True)
-            comment_body_elem = comment.find('[data-sigil="comment-body"]', first=True)
-            commenter_meta = None
-            if first_link:
-                url = utils.urljoin(FB_BASE_URL, first_link.attrs.get("href"))
-                name = first_link.text
-                if "\n" in name:
-                    commenter_meta, name = name.split("\n")
-            else:
-                # Adjacent div to comment body, if not logged in. No link to user page available in that case
-                url = None
-                elem = comment_body_elem.element.getprevious()
-                if elem is not None:
-                    name = elem.text
-                else:
-                    name = None
-
-            text = comment_body_elem.text
-            # Try to extract from the abbr element
-            date_element = comment.find('abbr', first=True)
-            if date_element:
-                date = utils.parse_datetime(date_element.text, search=False)
-            else:
-                date = None
-
-            result.append({
-                "comment_id": comment_id,
-                "commenter_url": url,
-                "commenter_name": name,
-                "commenter_meta": commenter_meta,
-                "comment_text": text,
-                "comment_time": date,
-            })
-        return {"comments_full": result}
+            result = self.parse_comment(comment)
+            replies = comment.find("div.async_elem[data-sigil='replies-see-more'] a[href]", first=True)
+            if replies:
+                logger.debug(f"{result['comment_id']} has replies")
+                url = utils.urljoin(FB_MOBILE_BASE_URL, replies.attrs["href"])
+                logger.debug(f"Fetching {url}")
+                response = self.request(url)
+                replies = response.html.find('div[data-sigil="comment"]')
+                result["replies"] = [self.parse_comment(reply) for reply in replies[1:]] # Skip first element, as it will be this comment itself
+            results.append(result)
+        return {"comments_full": results}
 
     def parse_share_and_reactions(self, html: str):
         bad_jsons = self.shares_and_reactions_regex.findall(html)
@@ -671,3 +692,5 @@ class PostExtractor:
 
 class GroupPostExtractor(PostExtractor):
     """Class for extracting posts from Facebook Groups rather than Pages"""
+    post_url_regex = re.compile(r'https://m.facebook.com/groups/[^/]+/permalink/')
+    post_story_regex = re.compile(r'href="(https://m.facebook.com/groups/[^/]+/permalink/\d+/)')
