@@ -1,6 +1,7 @@
 import itertools
 import logging
 import warnings
+import re
 from functools import partial
 from typing import Iterator, Union
 
@@ -43,7 +44,7 @@ class FacebookScraper:
         self.requests_kwargs = requests_kwargs
 
     def get_posts(self, account: str, **kwargs) -> Iterator[Post]:
-        iter_pages_fn = partial(iter_pages, account=account, request_fn=self.get)
+        iter_pages_fn = partial(iter_pages, account=account, request_fn=self.get, **kwargs)
         return self._generic_get_posts(extract_post, iter_pages_fn, **kwargs)
 
     def get_posts_by_url(self, post_urls, options={}, remove_source=True) -> Iterator[Post]:
@@ -57,7 +58,12 @@ class FacebookScraper:
             elem = response.html.find('article[data-ft],div.async_like[data-ft]', first=True)
             if not elem:
                 logger.warning("No raw posts (<article> elements) were found in this page.")
-            post = extract_post(elem, request_fn=self.get, options=options)
+            if post_url.startswith(utils.urljoin(FB_MOBILE_BASE_URL, "/groups/")):
+                post = extract_group_post(elem, request_fn=self.get, options=options)
+            else:
+                post = extract_post(elem, request_fn=self.get, options=options)
+            if not post.get("post_url"):
+                post["post_url"] = post_url
             if remove_source:
                 post.pop('source', None)
             yield post
@@ -129,6 +135,35 @@ class FacebookScraper:
                     result[header] = pairs
                 else:
                     result[header] = "\n".join(bits)
+        friend_opt = kwargs.get("friends")
+        if friend_opt:
+            limit = None
+            if type(friend_opt) in [int, float]:
+                limit = friend_opt
+            friend_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/friends/')
+            elems = []
+            while friend_url:
+                logger.debug(f"Requesting page from: {friend_url}")
+                response = self.get(friend_url)
+                elems.extend(response.html.find('div[data-sigil="undoable-action"]'))
+                if limit and len(elems) > limit:
+                    break
+                more = re.search(r'href:"(/[^/]+/friends[^"]+)"', response.text)
+                if more:
+                    friend_url = utils.urljoin(FB_MOBILE_BASE_URL, more.group(1))
+                else:
+                    break
+            logger.debug(f"Found {len(elems)} friends")
+            friends = []
+            for elem in elems:
+                name = elem.find("h3>a", first=True)
+                tagline = elem.find("div.notice.ellipsis", first=True).text
+                friends.append({
+                    "link": name.attrs.get("href"),
+                    "name": name.text,
+                    "tagline": tagline
+                })
+            result["Friends"] = friends
         return result
 
     def get_group_posts(self, group: Union[str, int], **kwargs) -> Iterator[Post]:
