@@ -20,10 +20,16 @@ def find_and_search(node, selector, pattern, cast=str):
 def parse_int(value: str) -> int:
     return int(''.join(filter(lambda c: c.isdigit(), value)))
 
+def convert_numeric_abbr(s):
+    mapping = {'k': 1000, 'm': 1e6}
+    if s[-1].isalpha():
+        return int(float(s[:-1]) * mapping[s[-1].lower()])
+    return int(s)
 
 def decode_css_url(url: str) -> str:
     url = re.sub(r'\\(..) ', r'\\x\g<1>', url)
     url, _ = codecs.unicode_escape_decode(url)
+    url, _ = codecs.unicode_escape_decode(url)
     return url
 
 
@@ -60,9 +66,19 @@ month = (
     r"Nov(?:ember)?|"
     r"Dec(?:ember)?"
 )
+day = (
+    r"Mon|"
+    r"Tue|"
+    r"Wed|"
+    r"Thu|"
+    r"Fri|"
+    r"Sat|"
+    r"Sun"
+)
 day_of_month = r"\d{1,2}"
 specific_date_md = f"(?:{month}) {day_of_month}" + r"(?:,? \d{4})?"
 specific_date_dm = f"{day_of_month} (?:{month})" + r"(?:,? \d{4})?"
+day_of_week = f"on ({day})"
 
 date = f"{specific_date_md}|{specific_date_dm}|Today|Yesterday"
 
@@ -75,7 +91,7 @@ relative_time_hours = r"\b\d{1,2} ?h(?:rs?)?"
 relative_time_mins = r"\b\d{1,2} ?mins?"
 relative_time = f"{relative_time_hours}|{relative_time_mins}"
 
-datetime_regex = re.compile(fr"({exact_time}|{relative_time})", re.IGNORECASE)
+datetime_regex = re.compile(fr"({exact_time}|{relative_time}|{day_of_week})", re.IGNORECASE)
 
 
 def parse_datetime(text: str, search=True) -> Optional[datetime]:
